.. pwt.jinja2js documentation master file, created by
   sphinx-quickstart on Fri Mar 18 10:06:55 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pwt.jinja2js
=======================

.. include:: description.rst.inc

Contents:

.. toctree::
   :maxdepth: 2

   usage
   compatibility

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

